# {{service.name}}

### **Options**

{% if service.metadata.options is iterable and (service.metadata.options is not string and service.metadata.options is not mapping) and service.metadata.options|length > 0 %}
### **Parameters**

| **Parameter Name** | Default | Required? | Type | Description |
| :--- | :--- | :--- | :--- | :--- |
{% for option in options %}| {{option.name}} | {{option.default}} | {{option.required}} | {{option.type}} | {{option.description}} |
{% if option.group|length > 0 -%}| _Additional options if {{option.name}} is True (option group : {{option.group.name}}_ ) | | | | |
{% for group_option in option.group.options %}| {{group_option.name}} | {{group_option.default}} | {{group_option.required}} | {{group_option.type}} | {{group_option.description}} |
{% endfor -%}
| _End of option group : {{option.group.name}}_ | | | | |
{% endif %}
{%- endfor %}
{% else %}No options are available for this service
{% endif %}

